==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/consumption/kotlin/inputs/BudgetFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.consumption.kotlin.inputs

import com.pulumi.azurenative.consumption.inputs.BudgetFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * May be used to filter budgets by resource group, resource, or meter.
 * @property and The logical "AND" expression. Must have at least 2 items.
 * @property dimensions Has comparison expression for a dimension
 * @property tags Has comparison expression for a tag
 */
public data class BudgetFilterArgs(
    public val and: Output<List<BudgetFilterPropertiesArgs>>? = null,
    public val dimensions: Output<BudgetComparisonExpressionArgs>? = null,
    public val tags: Output<BudgetComparisonExpressionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.consumption.inputs.BudgetFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.consumption.inputs.BudgetFilterArgs =
        com.pulumi.azurenative.consumption.inputs.BudgetFilterArgs.builder()
            .and(and?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .dimensions(dimensions?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tags(tags?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [BudgetFilterArgs].
 */
@PulumiTagMarker
public class BudgetFilterArgsBuilder internal constructor() {
    private var and: Output<List<BudgetFilterPropertiesArgs>>? = null

    private var dimensions: Output<BudgetComparisonExpressionArgs>? = null

    private var tags: Output<BudgetComparisonExpressionArgs>? = null

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("ioiuukactkhkwtik")
    public suspend fun and(`value`: Output<List<BudgetFilterPropertiesArgs>>) {
        this.and = value
    }

    @JvmName("vhwowkfjrhwjdfey")
    public suspend fun and(vararg values: Output<BudgetFilterPropertiesArgs>) {
        this.and = Output.all(values.asList())
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("uatrtkifvbnlytsf")
    public suspend fun and(values: List<Output<BudgetFilterPropertiesArgs>>) {
        this.and = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("wwfgpptomwuvubam")
    public suspend fun dimensions(`value`: Output<BudgetComparisonExpressionArgs>) {
        this.dimensions = value
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("rfofjpufqkcyivih")
    public suspend fun tags(`value`: Output<BudgetComparisonExpressionArgs>) {
        this.tags = value
    }

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("kwspswdwyvsfpfij")
    public suspend fun and(`value`: List<BudgetFilterPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("gqacusxodejrbtvf")
    public suspend fun and(argument: List<suspend BudgetFilterPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            BudgetFilterPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("florwsksylksmexg")
    public suspend fun and(vararg argument: suspend BudgetFilterPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            BudgetFilterPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("tphumjsvrlufwniw")
    public suspend fun and(argument: suspend BudgetFilterPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(BudgetFilterPropertiesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("gyyxwkunwypmwqpn")
    public suspend fun and(vararg values: BudgetFilterPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("idisihxpbpqraafk")
    public suspend fun dimensions(`value`: BudgetComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param argument Has comparison expression for a dimension
     */
    @JvmName("erbnrmfyemudraec")
    public suspend
    fun dimensions(argument: suspend BudgetComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = BudgetComparisonExpressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("fvmvskkrypascthb")
    public suspend fun tags(`value`: BudgetComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param argument Has comparison expression for a tag
     */
    @JvmName("vocnynnhgimsriia")
    public suspend fun tags(argument: suspend BudgetComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = BudgetComparisonExpressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tags = mapped
    }

    internal fun build(): BudgetFilterArgs = BudgetFilterArgs(
        and = and,
        dimensions = dimensions,
        tags = tags,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/consumption/kotlin/inputs/BudgetFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.consumption.kotlin.inputs

import com.pulumi.azurenative.consumption.inputs.BudgetFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * May be used to filter budgets by resource group, resource, or meter.
 * @property and The logical "AND" expression. Must have at least 2 items.
 * @property dimensions Has comparison expression for a dimension
 * @property tags Has comparison expression for a tag
 */
public data class BudgetFilterArgs(
    public val and: Output<List<BudgetFilterPropertiesArgs>>? = null,
    public val dimensions: Output<BudgetComparisonExpressionArgs>? = null,
    public val tags: Output<BudgetComparisonExpressionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.consumption.inputs.BudgetFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.consumption.inputs.BudgetFilterArgs =
        com.pulumi.azurenative.consumption.inputs.BudgetFilterArgs.builder()
            .and(and?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .dimensions(dimensions?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tags(tags?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [BudgetFilterArgs].
 */
@PulumiTagMarker
public class BudgetFilterArgsBuilder internal constructor() {
    private var and: Output<List<BudgetFilterPropertiesArgs>>? = null

    private var dimensions: Output<BudgetComparisonExpressionArgs>? = null

    private var tags: Output<BudgetComparisonExpressionArgs>? = null

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("oxfcnxlekvoedvkf")
    public suspend fun and(`value`: Output<List<BudgetFilterPropertiesArgs>>) {
        this.and = value
    }

    @JvmName("oeaxwfeieabuxncy")
    public suspend fun and(vararg values: Output<BudgetFilterPropertiesArgs>) {
        this.and = Output.all(values.asList())
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("vdyfcttfataykfxi")
    public suspend fun and(values: List<Output<BudgetFilterPropertiesArgs>>) {
        this.and = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("ldstwpifdymunbpx")
    public suspend fun dimensions(`value`: Output<BudgetComparisonExpressionArgs>) {
        this.dimensions = value
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("dubssuysukqbphkb")
    public suspend fun tags(`value`: Output<BudgetComparisonExpressionArgs>) {
        this.tags = value
    }

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("cvwpxhurucuvvtan")
    public suspend fun and(`value`: List<BudgetFilterPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("lhgjuhppcpfsgicg")
    public suspend fun and(argument: List<suspend BudgetFilterPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            BudgetFilterPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("nvsjcatkfuudsdvl")
    public suspend fun and(vararg argument: suspend BudgetFilterPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            BudgetFilterPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("pxvugswjmsqcwexj")
    public suspend fun and(argument: suspend BudgetFilterPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(BudgetFilterPropertiesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("oquseutaqukaoluc")
    public suspend fun and(vararg values: BudgetFilterPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("vbgtanvjuitexjrh")
    public suspend fun dimensions(`value`: BudgetComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param argument Has comparison expression for a dimension
     */
    @JvmName("lmqsfbvhtfrvgavl")
    public suspend
    fun dimensions(argument: suspend BudgetComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = BudgetComparisonExpressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("fxhcuurvqipurtbp")
    public suspend fun tags(`value`: BudgetComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param argument Has comparison expression for a tag
     */
    @JvmName("xaxflcdpcwyrokse")
    public suspend fun tags(argument: suspend BudgetComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = BudgetComparisonExpressionArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tags = mapped
    }

    internal fun build(): BudgetFilterArgs = BudgetFilterArgs(
        and = and,
        dimensions = dimensions,
        tags = tags,
    )
}
